# Design documents

This section contains desig-related documents for the *Kiara* project.

Most of those are not up-to-date, but they can help to understand certain design decisions, and why they were made.
